==> zn-plugin-workflow-0.1.5.tgz: package/web/src/exports/WFMyTodo.js <==
var React = require('react');
module.exports = React.createClass({
	getInitialState: function () {
		return {
			data: zn.store.post('/zn.plugin.workflow/my/todo'),
			items: [
				{ title: '模块', name: 'index_id_convert', width: 80 },
				{ title: '单号', name: 'code', width: 150, filter: { type: 'Input', opts: ['like'] } },
				{ title: '状态', name: 'state', width: 80 },
				{ title: '当前节点', name: 'current_state', width: 120 },
				{ title: '申请人', name: 'zn_create_user_convert', width: 100 },
				{ title: '申请时间', name: 'zn_create_time', width: 130 },
				{ title: '操作时间', name: 'zn_modify_time', width: 130 },
				{ title: '说明', name: 'zn_note', filter: { type: 'Input', opts: ['like'] } }
			]
		}
	},
	__onTableColumnRender: function (rowIndex, columnIndex, data, item, value){
		switch (columnIndex) {
			case 1:
				return <a href={'#'+zn.react.session.fixPath('/znpluginworkflow.WFInstance')+'?instanceId=' + data.id}>{value}</a>;
			case 2:
				switch (value) {
					case 1:
						return <span className="status" style={{backgroundColor: '#f0ad4e'}}>待处理</span>;
					case -1:
						return <span className="status" style={{backgroundColor: '#6def55'}}>已结束</span>;
					case -2:
						return <span className="status" style={{backgroundColor: '#dad8d8'}}>已取消</span>;
					case 2:
						return <span className="status" style={{backgroundColor: '#0d8c06'}}>已审核</span>;
				}
				break;
		}
	},
	render:function(){
		return (
			<zn.react.Page title="我的待办" className="zn-plugin-workflow-wf-my">
				<zn.react.PagerView
					view="Table"
					enableFilter={true}
					showHeader={true}
					columnRender={this.__onTableColumnRender}
					data={this.state.data}
					items={this.state.items}/>
			</zn.react.Page>
		);
	}
});

==> zn-plugin-workflow-0.1.14.tgz: package/web/src/exports/WFMyTodo.js <==
var React = require('react');
module.exports = React.createClass({
	getInitialState: function () {
		return {
			data: zn.store.post('/zn.plugin.workflow/my/todo'),
			items: [
				{ title: '模块', name: 'index_id_convert', width: 80 },
				{ title: '单号', name: 'code', width: 150, filter: { type: 'Input', opts: ['like'] } },
				{ title: '状态', name: 'state', width: 80 },
				{ title: '当前节点', name: 'current_state', width: 120 },
				{ title: '申请人', name: 'zn_create_user_convert', width: 100 },
				{ title: '申请时间', name: 'zn_create_time', width: 130 },
				{ title: '操作时间', name: 'zn_modify_time', width: 130 },
				{ title: '说明', name: 'zn_note', filter: { type: 'Input', opts: ['like'] } }
			]
		}
	},
	__onTableColumnRender: function (rowIndex, columnIndex, data, item, value){
		switch (columnIndex) {
			case 1:
				return <a data-tooltip={data.closed?'已关闭':''} style={{color:(data.closed?'#919191':null)}} href={'#'+zn.react.session.fixPath('/znpluginworkflow.wfinstance')+'?instanceId=' + data.id}>{value}</a>;
			case 2:
				switch (value) {
					case 1:
						return <span className="status" style={{backgroundColor: '#f0ad4e'}}>待处理</span>;
					case -1:
						return <span className="status" style={{backgroundColor: '#6def55'}}>已结束</span>;
					case -2:
						return <span className="status" style={{backgroundColor: '#dad8d8'}}>已取消</span>;
					case 2:
						return <span className="status" style={{backgroundColor: '#0d8c06'}}>已审核</span>;
				}
				break;
		}
	},
	render:function(){
		return (
			<zn.react.Page title="我的待办" className="zn-plugin-workflow-wf-my">
				<zn.react.PagerView
					view="Table"
					enableFilter={true}
					showHeader={true}
					columnRender={this.__onTableColumnRender}
					data={this.state.data}
					items={this.state.items}/>
			</zn.react.Page>
		);
	}
});
